@@ -6,6 +6,8 @@ PUT a Bag as a JSON object.
 These need some refactoring.
 """
 
+from httpexceptor import HTTP400, HTTP404, HTTP409, HTTP415
+
 from tiddlyweb.model.bag import Bag
 from tiddlyweb.model.collections import Tiddlers
 from tiddlyweb.model.policy import create_policy_check
@@ -16,7 +18,6 @@ from tiddlyweb.web import util as web
 from tiddlyweb.web.sendentity import send_entity
 from tiddlyweb.web.sendtiddlers import send_tiddlers
 from tiddlyweb.web.listentities import list_entities
-from tiddlyweb.web.http import HTTP400, HTTP404, HTTP409, HTTP415
 from tiddlyweb.web.validator import validate_bag, InvalidBagError
 
 
@@ -78,10 +79,11 @@ def get_tiddlers(environ, start_response):
     # will raise exception if there are problems
     bag.policy.allows(usersign, 'read')
 
-    if filters:
-        tiddlers = Tiddlers(title=title)
-    else:
-        tiddlers = Tiddlers(title=title, store=store)
+    tiddlers = Tiddlers(title=title)
+    if not filters:
+        tiddlers.store = store
+    tiddlers.bag = bag_name
+
     for tiddler in store.list_bag_tiddlers(bag):
         tiddlers.add(tiddler)
 
@@ -94,11 +96,7 @@ def list_bags(environ, start_response):
     """
     List all the bags that the current user can read.
     """
-    store = environ['tiddlyweb.store']
-    serialize_type, mime_type = web.get_serialize_type(environ)
-    serializer = Serializer(serialize_type, environ)
-    return list_entities(environ, start_response, mime_type, store.list_bags,
-            serializer.list_bags)
+    return list_entities(environ, start_response, 'list_bags')
 
 
 def put(environ, start_response):
